@@ -41,7 +41,7 @@
 #include <openobex/obex_const.h>
 
 #include "plugin.h"
-#include "logging.h"
+#include "log.h"
 #include "obex.h"
 #include "service.h"
 #include "phonebook.h"
@@ -431,7 +431,7 @@ static void cache_entry_done(void *user_data)
 
 	id = cache_find(&pbap->cache, pbap->find_handle);
 	if (id == NULL) {
-		debug("Entry %d not found on cache", pbap->find_handle);
+		DBG("Entry %d not found on cache", pbap->find_handle);
 		obex_object_set_io_flags(pbap, G_IO_ERR, -ENOENT);
 		return;
 	}
@@ -698,9 +698,6 @@ static void *vobject_pull_open(const char *name, int oflag, mode_t mode,
 	if (ret < 0)
 		goto fail;
 
-	if (size)
-		*size = OBJECT_SIZE_UNKNOWN;
-
 	return pbap;
 
 fail:
@@ -737,9 +734,6 @@ static void *vobject_list_open(const char *name, int oflag, mode_t mode,
 		goto fail;
 
 done:
-	if (size)
-		*size = OBJECT_SIZE_UNKNOWN;
-
 	return pbap;
 
 fail:
@@ -789,9 +783,6 @@ done:
 	if (ret < 0)
 		goto fail;
 
-	if (size)
-		*size = OBJECT_SIZE_UNKNOWN;
-
 	return pbap;
 
 fail:
